#!/usr/bin/env nix-shell
#!nix-shell deps.nix -i python

from pcbnew import *


PCB_FILE  = '../CyanStripe/CyanStripe.kicad_pcb'
SCAD_FILE = 'GENERATED.scad'


class SCAD:
  def __init__(self, filename):
    self.__filename = filename
    self.content = ''

  def print(self, any):
    self.content = self.content + f'{any}\n'

  def save(self):
    with open(self.__filename, 'w') as f:
      f.write(self.content)


pcb = LoadBoard(PCB_FILE)
scad = SCAD(SCAD_FILE)

scad.print('cube(30);')


mod = None

for module in pcb.GetModules():
  ref = str(module.GetReference())
  print(f'Module: {ref}')

  if not ref.startswith('R'):
    continue
#    mod = module
#    break

  x = module.GetPolyCourtyardFront()

  g = x.GraphicalItems()  # promising!

  b = g.GetBoundingBox()  # lets take this approach ATM

  x = ToMM(b.GetX())
  y = ToMM(b.GetY())
  w = ToMM(b.GetWidth())
  h = ToMM(b.GetHeight())

  scad.print(f'polygon([ [{x}, {y}], [{w+x}, {y}], [{x+w}, {y+h}], [{x}, {y+h}]]);')


  print('\n\n')




scad.save()
